Milham 2009 Results


Notes
-----
Data from a comprehensive resting-state reliability study. Resting scans are
derived from 26 participants at 3 different time points. Specifically,
intersession (>5 months apart), intrasession (<1 h apart), and multiscan
(across all 3 scans) reliability and consistency for both region-of-interest
and :term:`voxel`-wise analyses have been studied.


Content
-------
    :'func': Nifti images with :term:`BOLD` data
    :'anat_anon': Nifti images with subject anatomy
    :'anat_skull': Nifti images with subject skull information
    :'session': Information on session


References
----------
For more information on this dataset's structure, see
http://cercor.oxfordjournals.org/content/19/10/2209.full

`The Resting Brain: Unconstrained yet Reliable
<http://cercor.oxfordjournals.org/content/19/10/2209>`_
Z. Shehzad, A.M.C. Kelly, P.T. Reiss, D.G. Gee, K. Gotimer,
L.Q. Uddin, S.H. Lee, D.S. Margulies, A.K. Roy, B.B. Biswal,
E. Petkova, F.X. Castellanos and M.P. Milham.


Licence: unknown.
